# Description 
This is a python wrapper for moneycontrol.com, which provides you with the latest news and buisness news from moneycontrol.com

# Installation
`pip install moneycontrol-api`<br>
# Usage
`from moneycontrol import moneycontrol_api`<br>

# All supported functions
get_news<br>
get_latest_news<br>
get_buisness_news

# Output
```
--------------------
News Type: News
Title: EAM Jaishankar likely to visit Sri Lanka on Jan 19; talks on debt restructuring expected`

Link: https://www.moneycontrol.com/news/business/economy/eam-jaishankar-likely-to-visit-sri-lanka-on-jan-19-talks-on-debt-restructuring-expected-9868001.html 

Date: January 15, 2023 05:08 PM
-----------------
```
